'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var logger_1 = require("../logger");
var Q = require('q');
function setBasicQueries(schema) {
    schema.query.byUser = function (user) {
        if (user)
            this.where("userId").eq(user._id);
        return this;
    };
    return schema;
}
exports.setBasicQueries = setBasicQueries;
//export var TicketSchema;
function createQueryExecutor(model, queryBuilder) {
    var self = this;
    var executor = {};
    executor.execCount = function () {
        return self.execCount(model, queryBuilder);
    };
    executor.execFind = function (sortBy, currentPage, perPage) {
        return self.execFind(model, queryBuilder, sortBy, currentPage, perPage);
    };
    return Q.when(executor);
}
exports.createQueryExecutor = createQueryExecutor;
function execFindAndCound(query, res) {
    return function (queryExecutor) {
        var sortBy = query.sort;
        var currentPage = query.page || 1;
        var perPage = query.per_page || 200;
        return queryExecutor
            .execCount()
            .then(function (totalCount) {
            res.set('X-Total-Count', String(totalCount));
            return queryExecutor.execFind(sortBy, currentPage, perPage);
        });
    };
}
exports.execFindAndCound = execFindAndCound;
//Query utils
function execCount(model, queryBuilder) {
    logger_1.default.info(queryBuilder, model.collection.collectionName + ".execCount()");
    return queryBuilder(model.count(null)).exec();
}
exports.execCount = execCount;
function execFind(model, queryBuilder, sortBy, currentPage, perPage) {
    logger_1.default.info(queryBuilder, model.collection.collectionName + ".execFind()");
    var query = queryBuilder(model.find());
    if (sortBy)
        query.sort(sortBy);
    if (currentPage > 0 && perPage > 0)
        query
            .skip((currentPage - 1) * perPage)
            .limit(perPage);
    return query.exec();
}
exports.execFind = execFind;
